@@ -32,8 +32,6 @@
 
 #include <gkbd-config-private.h>
 
-#include <gkbd-config-registry-client.h>
-
 /**
  * GkbdIndicatorConfig
  */
@@ -46,6 +44,14 @@ const gchar GKBD_INDICATOR_CONFIG_KEY_ENABLED_PLUGINS[] =
     GKBD_INDICATOR_CONFIG_KEY_PREFIX "/enabledPlugins";
 const gchar GKBD_INDICATOR_CONFIG_KEY_SECONDARIES[] =
     GKBD_INDICATOR_CONFIG_KEY_PREFIX "/secondary";
+const gchar GKBD_INDICATOR_CONFIG_KEY_FONT_FAMILY[] =
+    GKBD_INDICATOR_CONFIG_KEY_PREFIX "/fontFamily";
+const gchar GKBD_INDICATOR_CONFIG_KEY_FONT_SIZE[] =
+    GKBD_INDICATOR_CONFIG_KEY_PREFIX "/fontSize";
+const gchar GKBD_INDICATOR_CONFIG_KEY_FOREGROUND_COLOR[] =
+    GKBD_INDICATOR_CONFIG_KEY_PREFIX "/foregroundColor";
+const gchar GKBD_INDICATOR_CONFIG_KEY_BACKGROUND_COLOR[] =
+    GKBD_INDICATOR_CONFIG_KEY_PREFIX "/backgroundColor";
 
 /**
  * static applet config functions
@@ -68,26 +74,6 @@ gkbd_indicator_config_free_enabled_plugins (GkbdIndicatorConfig *
 	}
 }
 
-/**
- * extern applet kbdConfig functions
- */
-void
-gkbd_indicator_config_free_images (GkbdIndicatorConfig * ind_config)
-{
-	GdkPixbuf *pi;
-	GSList *img_node;
-	while ((img_node = ind_config->images) != NULL) {
-		pi = GDK_PIXBUF (img_node->data);
-		/* It can be NULL - some images may be missing */
-		if (pi != NULL) {
-			gdk_pixbuf_unref (pi);
-		}
-		ind_config->images =
-		    g_slist_remove_link (ind_config->images, img_node);
-		g_slist_free_1 (img_node);
-	}
-}
-
 char *
 gkbd_indicator_config_get_images_file (GkbdIndicatorConfig *
 				       ind_config,
@@ -102,22 +88,21 @@ gkbd_indicator_config_get_images_file (GkbdIndicatorConfig *
 
 	if ((kbd_config->layouts_variants != NULL) &&
 	    (g_slist_length (kbd_config->layouts_variants) > group)) {
-		char *full_layout_name =
-		    (char *) g_slist_nth_data (kbd_config->
-					       layouts_variants, group);
+		char *full_layout_name = (char *)
+		    g_slist_nth_data (kbd_config->layouts_variants, group);
 
 		if (full_layout_name != NULL) {
 			char *l, *v;
 			gkbd_keyboard_config_split_items (full_layout_name,
 							  &l, &v);
 			if (l != NULL) {
-				// probably there is something in theme?
+				/* probably there is something in theme? */
 				icon_info = gtk_icon_theme_lookup_icon
 				    (ind_config->icon_theme, l, 48, 0);
 			}
 		}
 	}
-	// fallback to the default value
+	/* fallback to the default value */
 	if (icon_info == NULL) {
 		icon_info = gtk_icon_theme_lookup_icon
 		    (ind_config->icon_theme, "stock_dialog-error", 48, 0);
@@ -132,59 +117,39 @@ gkbd_indicator_config_get_images_file (GkbdIndicatorConfig *
 }
 
 void
-gkbd_indicator_config_load_images (GkbdIndicatorConfig * ind_config,
-				   GkbdKeyboardConfig * kbd_config)
+gkbd_indicator_config_load_image_filenames (GkbdIndicatorConfig *
+					    ind_config,
+					    GkbdKeyboardConfig *
+					    kbd_config)
 {
 	int i;
-	ind_config->images = NULL;
+	ind_config->image_filenames = NULL;
 
 	if (!ind_config->show_flags)
 		return;
 
 	for (i = xkl_engine_get_max_num_groups (ind_config->engine);
 	     --i >= 0;) {
-		GdkPixbuf *image = NULL;
 		char *image_file =
 		    gkbd_indicator_config_get_images_file (ind_config,
 							   kbd_config,
 							   i);
+		ind_config->image_filenames =
+		    g_slist_prepend (ind_config->image_filenames,
+				     image_file);
+	}
+}
 
-		if (image_file != NULL) {
-			GError *gerror = NULL;
-			image =
-			    gdk_pixbuf_new_from_file (image_file, &gerror);
-			if (image == NULL) {
-				GtkWidget *dialog =
-				    gtk_message_dialog_new (NULL,
-							    GTK_DIALOG_DESTROY_WITH_PARENT,
-							    GTK_MESSAGE_ERROR,
-							    GTK_BUTTONS_OK,
-							    _
-							    ("There was an error loading an image: %s"),
-							    gerror->
-							    message);
-				g_signal_connect (G_OBJECT (dialog),
-						  "response",
-						  G_CALLBACK
-						  (gtk_widget_destroy),
-						  NULL);
-
-				gtk_window_set_resizable (GTK_WINDOW
-							  (dialog), FALSE);
-
-				gtk_widget_show (dialog);
-				g_error_free (gerror);
-			}
-			xkl_debug (150,
-				   "Image %d[%s] loaded -> %p[%dx%d]\n",
-				   i, image_file, image,
-				   gdk_pixbuf_get_width (image),
-				   gdk_pixbuf_get_height (image));
-			g_free (image_file);
-		}
-		/* We append the image anyway - even if it is NULL! */
-		ind_config->images =
-		    g_slist_prepend (ind_config->images, image);
+void
+gkbd_indicator_config_free_image_filenames (GkbdIndicatorConfig *
+					    ind_config)
+{
+	while (ind_config->image_filenames) {
+		if (ind_config->image_filenames->data)
+			g_free (ind_config->image_filenames->data);
+		ind_config->image_filenames =
+		    g_slist_delete_link (ind_config->image_filenames,
+					 ind_config->image_filenames);
 	}
 }
 
@@ -236,27 +201,24 @@ gkbd_indicator_config_init (GkbdIndicatorConfig * ind_config,
 void
 gkbd_indicator_config_term (GkbdIndicatorConfig * ind_config)
 {
-#if 0
-	g_object_unref (G_OBJECT (ind_config->icon_theme));
-#endif
+	g_free (ind_config->font_family);
+	ind_config->font_family = NULL;
+
+	g_free (ind_config->foreground_color);
+	ind_config->foreground_color = NULL;
+
+	g_free (ind_config->background_color);
+	ind_config->background_color = NULL;
+
 	ind_config->icon_theme = NULL;
 
-	gkbd_indicator_config_free_images (ind_config);
+	gkbd_indicator_config_free_image_filenames (ind_config);
 
 	gkbd_indicator_config_free_enabled_plugins (ind_config);
 	g_object_unref (ind_config->conf_client);
 	ind_config->conf_client = NULL;
 }
 
-void
-gkbd_indicator_config_update_images (GkbdIndicatorConfig *
-				     ind_config,
-				     GkbdKeyboardConfig * kbd_config)
-{
-	gkbd_indicator_config_free_images (ind_config);
-	gkbd_indicator_config_load_images (ind_config, kbd_config);
-}
-
 void
 gkbd_indicator_config_load_from_gconf (GkbdIndicatorConfig * ind_config)
 {
@@ -286,6 +248,55 @@ gkbd_indicator_config_load_from_gconf (GkbdIndicatorConfig * ind_config)
 		gerror = NULL;
 	}
 
+
+	ind_config->font_family =
+	    gconf_client_get_string (ind_config->conf_client,
+				     GKBD_INDICATOR_CONFIG_KEY_FONT_FAMILY,
+				     &gerror);
+	if (gerror != NULL) {
+		g_warning ("Error reading configuration:%s\n",
+			   gerror->message);
+		ind_config->font_family = g_strdup ("Helvetica");
+		g_error_free (gerror);
+		gerror = NULL;
+	}
+
+	ind_config->font_size =
+	    gconf_client_get_int (ind_config->conf_client,
+				  GKBD_INDICATOR_CONFIG_KEY_FONT_SIZE,
+				  &gerror);
+	if (gerror != NULL) {
+		g_warning ("Error reading configuration:%s\n",
+			   gerror->message);
+		ind_config->font_size = 10;
+		g_error_free (gerror);
+		gerror = NULL;
+	}
+
+	ind_config->foreground_color =
+	    gconf_client_get_string (ind_config->conf_client,
+				     GKBD_INDICATOR_CONFIG_KEY_FOREGROUND_COLOR,
+				     &gerror);
+	if (gerror != NULL) {
+		g_warning ("Error reading configuration:%s\n",
+			   gerror->message);
+		g_error_free (gerror);
+		gerror = NULL;
+	}
+
+	ind_config->background_color =
+	    gconf_client_get_string (ind_config->conf_client,
+				     GKBD_INDICATOR_CONFIG_KEY_BACKGROUND_COLOR,
+				     &gerror);
+	if (gerror != NULL) {
+		g_warning ("Error reading configuration:%s\n",
+			   gerror->message);
+		g_error_free (gerror);
+		gerror = NULL;
+	}
+
+
+
 	gkbd_indicator_config_free_enabled_plugins (ind_config);
 	ind_config->enabled_plugins =
 	    gconf_client_get_list (ind_config->conf_client,
@@ -335,8 +346,7 @@ void
 gkbd_indicator_config_activate (GkbdIndicatorConfig * ind_config)
 {
 	xkl_engine_set_secondary_groups_mask (ind_config->engine,
-					      ind_config->
-					      secondary_groups_mask);
+					      ind_config->secondary_groups_mask);
 }
 
 void
@@ -355,6 +365,5 @@ void
 gkbd_indicator_config_stop_listen (GkbdIndicatorConfig * ind_config)
 {
 	gkbd_desktop_config_remove_listener (ind_config->conf_client,
-					     &ind_config->
-					     config_listener_id);
+					     &ind_config->config_listener_id);
 }
